lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite for Android: free password hash cracker in your pocket
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Thu, 7 Apr 2016 20:03:29 +0800
From:	Shannon Zhao <zhaoshenglong@...wei.com>
To:	<linux-arm-kernel@...ts.infradead.org>, <sstabellini@...nel.org>
CC:	<catalin.marinas@....com>, <will.deacon@....com>,
	<julien.grall@....com>, <david.vrabel@...rix.com>,
	<xen-devel@...ts.xen.org>, <devicetree@...r.kernel.org>,
	<linux-efi@...r.kernel.org>, <linux-kernel@...r.kernel.org>,
	<shannon.zhao@...aro.org>, <peter.huangpeng@...wei.com>
Subject: [PATCH v11 12/17] ARM64: ACPI: Check if it runs on Xen to enable or disable ACPI

From: Shannon Zhao <shannon.zhao@...aro.org>

When it's a Xen domain0 booting with ACPI, it will supply a /chosen and
a /hypervisor node in DT. So check if it needs to enable ACPI.

Signed-off-by: Shannon Zhao <shannon.zhao@...aro.org>
Reviewed-by: Stefano Stabellini <stefano.stabellini@...citrix.com>
Acked-by: Hanjun Guo <hanjun.guo@...aro.org>
---
 arch/arm64/kernel/acpi.c | 14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

diff --git a/arch/arm64/kernel/acpi.c b/arch/arm64/kernel/acpi.c
index d1ce8e2..57ee317 100644
--- a/arch/arm64/kernel/acpi.c
+++ b/arch/arm64/kernel/acpi.c
@@ -67,10 +67,15 @@ static int __init dt_scan_depth1_nodes(unsigned long node,
 {
 	/*
 	 * Return 1 as soon as we encounter a node at depth 1 that is
-	 * not the /chosen node.
+	 * not the /chosen node, or /hypervisor node with compatible
+	 * string "xen,xen".
 	 */
-	if (depth == 1 && (strcmp(uname, "chosen") != 0))
-		return 1;
+	if (depth == 1 && (strcmp(uname, "chosen") != 0)) {
+		if (strcmp(uname, "hypervisor") != 0 ||
+		    !of_flat_dt_is_compatible(node, "xen,xen"))
+			return 1;
+	}
+
 	return 0;
 }
 
@@ -184,7 +189,8 @@ void __init acpi_boot_table_init(void)
 	/*
 	 * Enable ACPI instead of device tree unless
 	 * - ACPI has been disabled explicitly (acpi=off), or
 	 * - the device tree is not empty (it has more than just a /chosen node)
 	 *   and ACPI has not been force enabled (acpi=force)
 	 */
 	if (param_acpi_off ||
@@ -184,7 +189,8 @@ void __init acpi_boot_table_init(void)
 	 * Enable ACPI instead of device tree unless
 	 * - ACPI has been disabled explicitly (acpi=off), or
-	 * - the device tree is not empty (it has more than just a /chosen node)
+	 * - the device tree is not empty (it has more than just a /chosen node,
+	 *   and a /hypervisor node when running on Xen)
 	 *   and ACPI has not been force enabled (acpi=force)
 	 */
-- 
2.0.4


Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ